@@ -16,7 +16,7 @@ def main(argv: List[str] = None) -> int:
     args = argument_parser.parse_args(argv)
     if hasattr(args, 'func'):
         cmd = args.func(args)  # see cli.py: bind_to_subparsers for all elements in _COMMANDS_
-        return cmd.run()
+        return cmd.cmd_run()
 
     argument_parser.print_help()
     return -1
