@@ -1,7 +1,20 @@
 from typing import Any
 
 
-class MirRuntimeError(Exception):
+class MirError(Exception):
+    """
+    error raised by ymir-command
+    """
+    def __init__(self, error_code: int, error_message: str) -> None:
+        super().__init__()
+        self.error_code = error_code
+        self.error_message = error_message
+
+    def __str__(self) -> str:
+        return f"code: {self.error_code}, content: {self.error_message}"
+
+
+class MirRuntimeError(MirError):
     """
 
     error raised by ymir-command
@@ -11,9 +24,7 @@ class MirRuntimeError(Exception):
 
     """
     def __init__(self, error_code: int, error_message: str, needs_new_commit: bool = True, mir_tasks: Any = None):
-        super().__init__(self)
-        self.error_code = error_code
-        self.error_message = error_message
+        super().__init__(error_code=error_code, error_message=error_message)
         self.needs_new_commit = needs_new_commit
         self.mir_tasks = mir_tasks
 
