@@ -1,11 +1,13 @@
 from dataclasses import asdict, dataclass, field
+from functools import wraps
 import logging
 import os
 import pathlib
+import time
 import requests
 import shutil
 import tarfile
-from typing import Any, Dict, List, Optional, Union
+from typing import Any, Callable, Dict, List, Optional, Union
 
 from PIL import Image, UnidentifiedImageError
 import yaml
@@ -15,6 +17,18 @@ from mir.tools.code import MirCode
 from mir.tools.errors import MirRuntimeError
 
 
+def time_it(f: Callable) -> Callable:
+    @wraps(f)
+    def wrapper(*args: tuple, **kwargs: Dict) -> Callable:
+        _start = time.time()
+        _ret = f(*args, **kwargs)
+        _cost = time.time() - _start
+        logging.info(f"|-{f.__name__} costs {_cost:.2f}s({_cost / 60:.2f}m).")
+        return _ret
+
+    return wrapper
+
+
 # project
 def project_root() -> str:
     root = str(pathlib.Path(__file__).parent.parent.parent.absolute())
@@ -172,7 +186,7 @@ class ModelStorage:
         self.class_names = self.executor_config.get('class_names', [])
         # check valid
         if not self.models or not self.executor_config or not self.task_context or not self.class_names:
-            raise MirRuntimeError(error_code=MirCode.RC_CMD_INVALID_MIR_FILE,
+            raise MirRuntimeError(error_code=MirCode.RC_CMD_INVALID_ARGS,
                                   error_message='ModelStorage invalid: not enough infomations')
 
     def as_dict(self) -> Dict[str, Any]:
@@ -240,3 +254,8 @@ def _unpack_models(tar_file: str, dest_root: str) -> ModelStorage:
                                  task_context=ymir_info_dict.get('task_context', {}))
 
     return model_storage
+
+
+def map_gpus_zero_index(gpu_id: str) -> str:
+    gpu_count = len(gpu_id.split(',')) if gpu_id else 0
+    return ','.join([str(i) for i in range(gpu_count)])
